@@ -14,8 +14,11 @@ back to the defaults.
 """
 from .module_loading import import_string
 from pathlib import Path
+from dotenv import load_dotenv
 import os
 
+load_dotenv()
+
 django_imported = False
 try:
     from django.conf import settings
